==> react-ui-5.0.0.tgz: package/Clickable.js <==
/******/ (() => {
    // webpackBootstrap
    /******/ "use strict";
    /******/ // The require scope
    /******/    var e = {};
    /******/
    /************************************************************************/
    /******/ /* webpack/runtime/compat get default export */
    /******/    (() => {
        /******/ // getDefaultExport function for compatibility with non-harmony modules
        /******/ e.n = n => {
            /******/ var r = n && n.__esModule ? 
            /******/ () => n["default"]
            /******/ : () => n
            /******/;
            e.d(r, {
                a: r
            });
            /******/            return r;
            /******/        };
        /******/    })();
    /******/
    /******/ /* webpack/runtime/define property getters */
    /******/    (() => {
        /******/ // define getter functions for harmony exports
        /******/ e.d = (n, r) => {
            /******/ for (var t in r) {
                /******/ if (e.o(r, t) && !e.o(n, t)) {
                    /******/ Object.defineProperty(n, t, {
                        enumerable: true,
                        get: r[t]
                    });
                    /******/                }
                /******/            }
            /******/        };
        /******/    })();
    /******/
    /******/ /* webpack/runtime/hasOwnProperty shorthand */
    /******/    (() => {
        /******/ e.o = (e, n) => Object.prototype.hasOwnProperty.call(e, n)
        /******/;
    })();
    /******/
    /******/ /* webpack/runtime/make namespace object */
    /******/    (() => {
        /******/ // define __esModule on exports
        /******/ e.r = e => {
            /******/ if (typeof Symbol !== "undefined" && Symbol.toStringTag) {
                /******/ Object.defineProperty(e, Symbol.toStringTag, {
                    value: "Module"
                });
                /******/            }
            /******/            Object.defineProperty(e, "__esModule", {
                value: true
            });
            /******/        };
        /******/    })();
    /******/
    /************************************************************************/    var n = {};
    // ESM COMPAT FLAG
        e.r(n);
    // EXPORTS
        e.d(n, {
        NavigationContext: () => /* reexport */ m,
        NavigationProvider: () => /* reexport */ y,
        default: () => /* reexport */ R,
        isInternalLink: () => /* reexport */ j,
        isRootRelativeLink: () => /* reexport */ S
    });
    // CONCATENATED MODULE: external "react"
    const r = require("react");
    var t =  e.n(r);
    // CONCATENATED MODULE: external "prop-types"
    const i = require("prop-types");
    var a =  e.n(i);
    // CONCATENATED MODULE: external "lodash/has"
    const o = require("lodash/has");
    // CONCATENATED MODULE: external "lodash/isString"
    const l = require("lodash/isString");
    var u =  e.n(l);
    // CONCATENATED MODULE: external "lodash/omit"
    const d = require("lodash/omit");
    var c =  e.n(d);
    // CONCATENATED MODULE: external "styled-components"
    const s = require("styled-components");
    var f =  e.n(s);
    // CONCATENATED MODULE: external "@splunk/themes"
    const v = require("@splunk/themes");
    // CONCATENATED MODULE: ./src/Clickable/ClickableStyles.ts
    var b = f().a.withConfig({
        displayName: "ClickableStyles__StyledA",
        componentId: "sc-7al1vw-0"
    })([ "", " cursor:pointer;&[disabled],&[aria-disabled='true']{cursor:not-allowed;color:", ";}&::-moz-focus-inner{border:0;padding:0;}" ], v.mixins.reset("inline"), v.variables.contentColorDisabled);
    // CONCATENATED MODULE: ./src/Clickable/NavigationProvider.tsx
    /** @public */
    var p = {
        children: a().node,
        onClick: a().func,
        onLinkClick: a().func,
        transformUrl: a().func
    };
    var m =  t().createContext({});
    /**
 * Used to provide an override for the `onClick` for links for single page applications so that
 * internal links can navigate without a page reload.
 */    function y(e) {
        var n = e.children, i = e.onClick, a = e.onLinkClick, o = e.transformUrl;
        // @docs-props-type NavigationProviderProps
                var l = (0, r.useMemo)((function() {
            return {
                onClick: i,
                onLinkClick: a,
                transformUrl: o
            };
        }), [ i, a, o ]);
        
        return t().createElement(m.Provider, {
            value: l
        }, n);
    }
    y.propTypes = p;
    // CONCATENATED MODULE: ./src/utils/updateReactRef.ts
    /**
 * Updates a React ref. Callback refs and object refs (from `createRef` and `useRef`) are supported.
 *
 * @param ref - The React callback or object ref. Can be `null` or `undefined`.
 * @param current - The new value of the ref.
 */
    function k(e, n) {
        if (e) {
            if (typeof e === "function") {
                e(n);
            } else {
                // the public signature of this util uses React.Ref<T> to mirror the way React types refs.
                // the intention here is to signal "we will take care of setting 'current', not you".
                e.current = n;
 // eslint-disable-line no-param-reassign
                        }
        }
    }
    // CONCATENATED MODULE: ./src/Clickable/Clickable.tsx
    function C() {
        return C = Object.assign ? Object.assign.bind() : function(e) {
            for (var n = 1; n < arguments.length; n++) {
                var r = arguments[n];
                for (var t in r) {
                    ({}).hasOwnProperty.call(r, t) && (e[t] = r[t]);
                }
            }
            return e;
        }, C.apply(null, arguments);
    }
    function g(e, n) {
        if (null == e) return {};
        var r, t, i = O(e, n);
        if (Object.getOwnPropertySymbols) {
            var a = Object.getOwnPropertySymbols(e);
            for (t = 0; t < a.length; t++) {
                r = a[t], n.includes(r) || {}.propertyIsEnumerable.call(e, r) && (i[r] = e[r]);
            }
        }
        return i;
    }
    function O(e, n) {
        if (null == e) return {};
        var r = {};
        for (var t in e) {
            if ({}.hasOwnProperty.call(e, t)) {
                if (n.includes(t)) continue;
                r[t] = e[t];
            }
        }
        return r;
    }
    var h = /^[a-z0-9]+:/;
    var w = /^\/\//;
    var P = /^\//;
    var S = function e(n) {
        return n != null && P.test(n);
    };
    var j = function e(n) {
        return n != null && !h.test(n) && !w.test(n);
    };
    var x = {
        children: a().node,
        disabled: a().oneOfType([ a().bool, a().oneOf([ "dimmed", "disabled" ]) ]),
        elementRef: a().oneOfType([ a().func, a().object ]),
        onClick: a().func,
        openInNewContext: a().bool,
        navigationLabel: a().string,
        to: a().oneOfType([ a().string, a().oneOf([ undefined ]) ])
    };
    function L(e) {
        return e !== undefined;
    }
    /**
 * `Clickable` renders as a `button` element, or as an `a` element if the `to` prop is set
 * and the `disabled` prop is `false`. This is called link mode.
 */    var I =  t().forwardRef((function(e, 
    // SUI-7623 - needs to be specified for react-docgen versions less than 7.1.0
    n) {
        var i = e.children, a = e.disabled, o = e.elementRef, l = e.navigationLabel, d = e.onClick, s = e.openInNewContext, f = e.tag, v = e.to, p = g(e, [ "children", "disabled", "elementRef", "navigationLabel", "onClick", "openInNewContext", "tag", "to" ]);
        // @docs-props-type ClickablePropsBase
                var y = (0, r.useContext)(m), O = y.onClick, h = y.onLinkClick, w = y.transformUrl;
        (0, r.useEffect)((function() {
            if (false) {}
            // this effect only runs once
            // eslint-disable-next-line react-hooks/exhaustive-deps
                }), []);
        var P = (0, r.useCallback)((function(e) {
            k(o, e);
            k(n, e);
        }), [ o, n ]);
        // memoizing this result causes TS to lose track of the type guard established by isLinkCheck
                var x = L(v);
        // ideally we wouldn't need to pass "to" as "toValue" here
        // but without doing that TS thinks the return value of this is
        // string | undefined which doesn't work for usages of this function
                var I = (0, r.useCallback)((function(e) {
            return w != null ? w(e, {
                isInternal: j(e),
                isRootRelative: S(e)
            }) : e;
        }), [ w ]);
        var R = (0, r.useCallback)((function(e) {
            if (x) {
                // when user command-click on mac or ctrl-click on other platforms, and
                // Tag is an <a>, let the click pass through, let the <a> to achieve user's
                // intent of 'open in new context'
                // on mac, ctrl-click will be caught and open option menu even before hitting
                // the DOM, so we're safe to check both metaKey and ctrlKey here
                // without platform sniffing
                if ((e.metaKey || e.ctrlKey) && v) {
                    return;
                }
            }
            d === null || d === void 0 ? void 0 : d(e);
            var n = d == null && O != null;
            if (x && (n || h != null)) {
                var r = l;
                if (!r && u()(i)) {
                    r = i;
                }
                var t = {
                    to: I(v),
                    originalTo: v,
                    openInNewContext: s,
                    label: r
                };
                if (n) {
                    O(e, t);
                }
                h === null || h === void 0 ? void 0 : h(e, t);
            }
        }), [ i, I, x, l, d, O, h, s, v ]);
        // Only set the href attribute when enabled and therefore using an <a> tag
                if (x && f !== "button") {
            if (a) {
                
                return t().createElement(b, C({
                    "data-test": "clickable",
                    "data-test-disabled": a,
                    ref: P,
                    role: "link",
                    "aria-disabled": "true"
                }, p), i);
            }
            var T = s ? "_blank" : undefined;
            var q = s && j(v) ? "noopener noreferrer" : undefined;
            
            return t().createElement(b, C({
                "data-test": "clickable",
                ref: P,
                href: I(v),
                target: T,
                rel: q,
                onClick: R
            }, c()(p)), i);
        }
        // button variant
                var N = a === true || a === "dimmed" || undefined;
        var _;
        if (N) {
            _ = "dimmed";
        } else if (a === "disabled") {
            _ = "disabled";
        }
        
        return t().createElement(b, C({
            as: "button",
            "aria-disabled": N,
            "data-test": "clickable",
            "data-test-disabled": _,
            ref: P,
            type: "button",
            disabled: a === "disabled",
            onClick: d && !a ? R : undefined
        }, c()(p, "disabled")), i);
    }));
    I.propTypes = x;
    /* harmony default export */    const R = I;
    // forwardRef appears to prevent TS from inferring ClickableProps in components that import Clickable
    // so we need to export it separately to prevent the TS build from failing with:
    // "... has or is using name 'ClickablePropsBase' from external module "...packages/react-ui/src/Clickable/Clickable" but cannot be named."
        // CONCATENATED MODULE: ./src/Clickable/index.ts
    module.exports = n;
    /******/})();

==> react-ui-5.1.0.tgz: package/Clickable.js <==
/******/ (() => {
    // webpackBootstrap
    /******/ "use strict";
    /******/ // The require scope
    /******/    var e = {};
    /******/
    /************************************************************************/
    /******/ /* webpack/runtime/compat get default export */
    /******/    (() => {
        /******/ // getDefaultExport function for compatibility with non-harmony modules
        /******/ e.n = n => {
            /******/ var r = n && n.__esModule ? 
            /******/ () => n["default"]
            /******/ : () => n
            /******/;
            e.d(r, {
                a: r
            });
            /******/            return r;
            /******/        };
        /******/    })();
    /******/
    /******/ /* webpack/runtime/define property getters */
    /******/    (() => {
        /******/ // define getter functions for harmony exports
        /******/ e.d = (n, r) => {
            /******/ for (var t in r) {
                /******/ if (e.o(r, t) && !e.o(n, t)) {
                    /******/ Object.defineProperty(n, t, {
                        enumerable: true,
                        get: r[t]
                    });
                    /******/                }
                /******/            }
            /******/        };
        /******/    })();
    /******/
    /******/ /* webpack/runtime/hasOwnProperty shorthand */
    /******/    (() => {
        /******/ e.o = (e, n) => Object.prototype.hasOwnProperty.call(e, n)
        /******/;
    })();
    /******/
    /******/ /* webpack/runtime/make namespace object */
    /******/    (() => {
        /******/ // define __esModule on exports
        /******/ e.r = e => {
            /******/ if (typeof Symbol !== "undefined" && Symbol.toStringTag) {
                /******/ Object.defineProperty(e, Symbol.toStringTag, {
                    value: "Module"
                });
                /******/            }
            /******/            Object.defineProperty(e, "__esModule", {
                value: true
            });
            /******/        };
        /******/    })();
    /******/
    /************************************************************************/    var n = {};
    // ESM COMPAT FLAG
        e.r(n);
    // EXPORTS
        e.d(n, {
        NavigationContext: () => /* reexport */ m,
        NavigationProvider: () => /* reexport */ y,
        default: () => /* reexport */ R,
        isInternalLink: () => /* reexport */ j,
        isRootRelativeLink: () => /* reexport */ S
    });
    // CONCATENATED MODULE: external "react"
    const r = require("react");
    var t =  e.n(r);
    // CONCATENATED MODULE: external "lodash/has"
    const i = require("lodash/has");
    // CONCATENATED MODULE: external "lodash/isString"
    const a = require("lodash/isString");
    var o =  e.n(a);
    // CONCATENATED MODULE: external "lodash/omit"
    const l = require("lodash/omit");
    var u =  e.n(l);
    // CONCATENATED MODULE: external "prop-types"
    const d = require("prop-types");
    var c =  e.n(d);
    // CONCATENATED MODULE: external "styled-components"
    const s = require("styled-components");
    var f =  e.n(s);
    // CONCATENATED MODULE: external "@splunk/themes"
    const v = require("@splunk/themes");
    // CONCATENATED MODULE: ./src/Clickable/ClickableStyles.ts
    var b = f().a.withConfig({
        displayName: "ClickableStyles__StyledA",
        componentId: "sc-7al1vw-0"
    })([ "", " cursor:pointer;&[disabled],&[aria-disabled='true']{cursor:not-allowed;color:", ";}&::-moz-focus-inner{border:0;padding:0;}" ], v.mixins.reset("inline"), v.variables.contentColorDisabled);
    // CONCATENATED MODULE: ./src/Clickable/NavigationProvider.tsx
    /** @public */
    var p = {
        children: c().node,
        onClick: c().func,
        onLinkClick: c().func,
        transformUrl: c().func
    };
    var m =  t().createContext({});
    /**
 * Used to provide an override for the `onClick` for links for single page applications so that
 * internal links can navigate without a page reload.
 */    function y(e) {
        var n = e.children, i = e.onClick, a = e.onLinkClick, o = e.transformUrl;
        // @docs-props-type NavigationProviderProps
                var l = (0, r.useMemo)((function() {
            return {
                onClick: i,
                onLinkClick: a,
                transformUrl: o
            };
        }), [ i, a, o ]);
        
        return t().createElement(m.Provider, {
            value: l
        }, n);
    }
    y.propTypes = p;
    // CONCATENATED MODULE: ./src/utils/updateReactRef.ts
    /**
 * Updates a React ref. Callback refs and object refs (from `createRef` and `useRef`) are supported.
 *
 * @param ref - The React callback or object ref. Can be `null` or `undefined`.
 * @param current - The new value of the ref.
 */
    function k(e, n) {
        if (e) {
            if (typeof e === "function") {
                e(n);
            } else {
                // the public signature of this util uses React.Ref<T> to mirror the way React types refs.
                // the intention here is to signal "we will take care of setting 'current', not you".
                e.current = n;
 // eslint-disable-line no-param-reassign
                        }
        }
    }
    // CONCATENATED MODULE: ./src/Clickable/Clickable.tsx
    function C() {
        return C = Object.assign ? Object.assign.bind() : function(e) {
            for (var n = 1; n < arguments.length; n++) {
                var r = arguments[n];
                for (var t in r) {
                    ({}).hasOwnProperty.call(r, t) && (e[t] = r[t]);
                }
            }
            return e;
        }, C.apply(null, arguments);
    }
    function g(e, n) {
        if (null == e) return {};
        var r, t, i = O(e, n);
        if (Object.getOwnPropertySymbols) {
            var a = Object.getOwnPropertySymbols(e);
            for (t = 0; t < a.length; t++) {
                r = a[t], n.includes(r) || {}.propertyIsEnumerable.call(e, r) && (i[r] = e[r]);
            }
        }
        return i;
    }
    function O(e, n) {
        if (null == e) return {};
        var r = {};
        for (var t in e) {
            if ({}.hasOwnProperty.call(e, t)) {
                if (n.includes(t)) continue;
                r[t] = e[t];
            }
        }
        return r;
    }
    var h = /^[a-z0-9]+:/;
    var w = /^\/\//;
    var P = /^\//;
    var S = function e(n) {
        return n != null && P.test(n);
    };
    var j = function e(n) {
        return n != null && !h.test(n) && !w.test(n);
    };
    var x = {
        children: c().node,
        disabled: c().oneOfType([ c().bool, c().oneOf([ "dimmed", "disabled" ]) ]),
        elementRef: c().oneOfType([ c().func, c().object ]),
        onClick: c().func,
        openInNewContext: c().bool,
        navigationLabel: c().string,
        to: c().oneOfType([ c().string, c().oneOf([ undefined ]) ])
    };
    function L(e) {
        return e !== undefined;
    }
    /**
 * `Clickable` renders as a `button` element, or as an `a` element if the `to` prop is set
 * and the `disabled` prop is `false`. This is called link mode.
 */    var I =  t().forwardRef((function(e, 
    // SUI-7623 - needs to be specified for react-docgen versions less than 7.1.0
    n) {
        var i = e.children, a = e.disabled, l = e.elementRef, d = e.navigationLabel, c = e.onClick, s = e.openInNewContext, f = e.tag, v = e.to, p = g(e, [ "children", "disabled", "elementRef", "navigationLabel", "onClick", "openInNewContext", "tag", "to" ]);
        // @docs-props-type ClickablePropsBase
                var y = (0, r.useContext)(m), O = y.onClick, h = y.onLinkClick, w = y.transformUrl;
        (0, r.useEffect)((function() {
            if (false) {}
            // this effect only runs once
            // eslint-disable-next-line react-hooks/exhaustive-deps
                }), []);
        var P = (0, r.useCallback)((function(e) {
            k(l, e);
            k(n, e);
        }), [ l, n ]);
        // memoizing this result causes TS to lose track of the type guard established by isLinkCheck
                var x = L(v);
        // ideally we wouldn't need to pass "to" as "toValue" here
        // but without doing that TS thinks the return value of this is
        // string | undefined which doesn't work for usages of this function
                var I = (0, r.useCallback)((function(e) {
            return w != null ? w(e, {
                isInternal: j(e),
                isRootRelative: S(e)
            }) : e;
        }), [ w ]);
        var R = (0, r.useCallback)((function(e) {
            if (x) {
                // when user command-click on mac or ctrl-click on other platforms, and
                // Tag is an <a>, let the click pass through, let the <a> to achieve user's
                // intent of 'open in new context'
                // on mac, ctrl-click will be caught and open option menu even before hitting
                // the DOM, so we're safe to check both metaKey and ctrlKey here
                // without platform sniffing
                if ((e.metaKey || e.ctrlKey) && v) {
                    return;
                }
            }
            c === null || c === void 0 ? void 0 : c(e);
            var n = c == null && O != null;
            if (x && (n || h != null)) {
                var r = d;
                if (!r && o()(i)) {
                    r = i;
                }
                var t = {
                    to: I(v),
                    originalTo: v,
                    openInNewContext: s,
                    label: r
                };
                if (n) {
                    O(e, t);
                }
                h === null || h === void 0 ? void 0 : h(e, t);
            }
        }), [ i, I, x, d, c, O, h, s, v ]);
        // Only set the href attribute when enabled and therefore using an <a> tag
                if (x && f !== "button") {
            if (a) {
                
                return t().createElement(b, C({
                    "data-test": "clickable",
                    "data-test-disabled": a,
                    ref: P,
                    role: "link",
                    "aria-disabled": "true"
                }, p), i);
            }
            var T = s ? "_blank" : undefined;
            var q = s && j(v) ? "noopener noreferrer" : undefined;
            
            return t().createElement(b, C({
                "data-test": "clickable",
                ref: P,
                href: I(v),
                target: T,
                rel: q,
                onClick: R
            }, u()(p)), i);
        }
        // button variant
                var N = a === true || a === "dimmed" || undefined;
        var _;
        if (N) {
            _ = "dimmed";
        } else if (a === "disabled") {
            _ = "disabled";
        }
        
        return t().createElement(b, C({
            as: "button",
            "aria-disabled": N,
            "data-test": "clickable",
            "data-test-disabled": _,
            ref: P,
            type: "button",
            disabled: a === "disabled",
            onClick: c && !a ? R : undefined
        }, u()(p, "disabled")), i);
    }));
    I.propTypes = x;
    /* harmony default export */    const R = I;
    // forwardRef appears to prevent TS from inferring ClickableProps in components that import Clickable
    // so we need to export it separately to prevent the TS build from failing with:
    // "... has or is using name 'ClickablePropsBase' from external module "...packages/react-ui/src/Clickable/Clickable" but cannot be named."
        // CONCATENATED MODULE: ./src/Clickable/index.ts
    module.exports = n;
    /******/})();
